--Shadow of the Blade
--Kevin Pereksta
--Idea by Scott Pereksta
--Music Scott Pereksta

---Load Maps
local Deck = require('MAPS/deck')

--Load Libs
local MapSetup = require('LIBS/MAPSETUP')
local Drawing = require('LIBS/DRAWING')
local Movement = require('LIBS/MOVEMENT')

function love.load()
	
	love.graphics.setMode(20 * 32, 20 * 32, false, true, 0)
	love.graphics.setColorMode("replace")
	love.graphics.setCaption("Silence of the Blade")
	
	BaseLayer = love.graphics.newCanvas()
	ShadowLayer = love.graphics.newCanvas()
	ShadowCasterLayer = love.graphics.newCanvas()
	LightLayer = love.graphics.newCanvas()
	
	--Load Sounds
	
	Steps_SND = love.audio.newSource("SND/STEPS.ogg")
	
	Songs = {}
	Songs[1] = love.audio.newSource("SND/SNG1.ogg")
	Songs[2] = love.audio.newSource("SND/SNG2.ogg")
	
	Songs[1]:setLooping(true)
	Songs[2]:setLooping(true)
	
	love.audio.play(Songs[2])
	
	--Load Images
	
	--Player
	Player = {}
	
	--Still
	Player[1] = love.graphics.newImage("PICS/Player/Player.png")
	
	--Slash Animation
	Player[2] = love.graphics.newImage("PICS/Player/PlayerSlash1.png")
	Player[3] = love.graphics.newImage("PICS/Player/PlayerSlash2.png")
	Player[4] = love.graphics.newImage("PICS/Player/PlayerSlash3.png")

	--Cop
	Cop = {}
	
	--Still
	Cop[1] = love.graphics.newImage("PICS/Cop/Cop.png")
	
	--Shoot Animation
	Cop[2] = love.graphics.newImage("PICS/Cop/CopShoot1.png")
	Cop[3] = love.graphics.newImage("PICS/Cop/CopShoot2.png")
	Cop[4] = love.graphics.newImage("PICS/Cop/CopShoot3.png")
	
	--Tiles
	Tiles = {}
	Tiles[0] = love.graphics.newImage("PICS/TERRAIN/Grass.png")
	Tiles[1] = love.graphics.newImage("PICS/TERRAIN/BOX.png")
	Tiles[2] = love.graphics.newImage("PICS/TERRAIN/CONCRETE.png")
	Tiles[3] = love.graphics.newImage("PICS/TERRAIN/WATER.png")
	Tiles[4] = love.graphics.newImage("PICS/TERRAIN/WOOD.png")
	Tiles[5] = love.graphics.newImage("PICS/TERRAIN/STONE.png")
	Tiles[6] = love.graphics.newImage("PICS/TERRAIN/WOODFLOOR.png")
	
	--Lantern
	Lantern = love.graphics.newImage("PICS/Lantern.png")
	
	
	
	BURNRATE = 0.5
	
	--Set some Variables
	
	GAME = {}
	GAME.STATE = 0
	GAME.MODE = 0
	
	PLAYER = {}
	PLAYER.HEALTH = 100
	PLAYER.LANTERN = true
	PLAYER.LANTERNOIL = 100
	PLAYER.X = 0
	PLAYER.Y = 0
	PLAYER.ROTATION = 0
	PLAYER.STATE = 0
	
	
	MOVE_SPEED = 3
	
	
	MAP = {}
	COLLISION = {}
	SHADOW = {}
	SHADOWCAST = {}
	SPAWN = {}	
	
	CURSOR = {}
	CURSOR.X = 0
	CURSOR.Y = 0
end

function love.draw()
	--Game State
	if GAME.MODE == 2 then
		love.graphics.setCanvas(BaseLayer)
		drawBase()   --Draws Non ShadowCasting layer
		drawPlayers() --Draws Players
		
		love.graphics.setCanvas(ShadowLayer)
		ShadowLayer:clear()
		drawShadows(PLAYER.X, PLAYER.Y, 1024, PLAYER.ROTATION, 0, 0) --Draws Shadows
		
		love.graphics.setCanvas(ShadowCasterLayer)
		drawCasters() --Draws Shadowcasting layer
		
		
		love.graphics.setCanvas(LightLayer)
		LightLayer:clear()
		love.graphics.clear(0, 0, 0)
		love.graphics.setBlendMode("alpha")
		
		if PLAYER.LANTERN then
			love.graphics.draw(Lantern, PLAYER.X * 32 - 256, PLAYER.Y * 32 - 256)
		end
		
		love.graphics.setCanvas()
		love.graphics.draw(BaseLayer)
		love.graphics.draw(ShadowLayer)
		love.graphics.draw(ShadowCasterLayer)
		love.graphics.draw(LightLayer)
		
		drawHUD()
		
	end
end


DELTA = 0
function love.update(dt)
	love.graphics.setCaption("Silence of the Blade      FPS: " .. love.timer.getFPS())

	CURSOR.X = love.mouse.getX()
	CURSOR.Y = love.mouse.getY()
	
	DELTA = dt

	--Splash
	if GAME.MODE == 0 then
		GAME.MODE = 1
	end
	
	--Menu
	if GAME.MODE == 1 then
		LoadMap(1)
		PLAYER.X = SPAWN[1]
		PLAYER.Y = SPAWN[2]
		GAME.MODE = 2
	end		
	
	--In Game
	if GAME.MODE == 2 then
		getAimAngle()

		
		if love.keyboard.isDown("a") then
			MoveLeft()
		end
		if love.keyboard.isDown("d") then
			MoveRight()
		end
		if love.keyboard.isDown("w") then
			MoveUp()
		end
		if love.keyboard.isDown("s") then
			MoveDown()
		end
		
		if love.keyboard.isDown("e") then
			PLAYER.LANTERN = false
		end
		if love.keyboard.isDown("q") then
			PLAYER.LANTERN = true
		end
		
		if PLAYER.LANTERN then
			if PLAYER.LANTERNOIL > 0 then
				PLAYER.LANTERNOIL = PLAYER.LANTERNOIL - (BURNRATE * DELTA)
			elseif PLAYER.LANTERNOIL < 0 then
				PLAYER.LANTERN = false
			end
		end
		
	end
end